/*
 *  led_blink.c
 *  
 *
 *  Created by Roy Shilkrot on 5/23/12.
 *  Copyright 2012 MIT. All rights reserved.
 *
 */

#include "led_blink.h"

#include <inttypes.h>
#include <avr/io.h>
#include <util/delay.h>

void led_blink(const int _d) {
	PORTD |= 0x20;
	_delay_loop_2(_d);
	PORTD &= ~(0x20);
	_delay_loop_2(_d);	
}	

int main(void) {
	/* set PORTD for output (LED) on PD5 */
	DDRD |= _BV(PD5);
	/* set PORTC for input (IR) on PC2 */
	DDRC = ~_BV(PC2);
	/* set PORTD for output (SERVOR) on PD0 */
	DDRD |= _BV(PD0);

	led_blink(100);
	
#define HIGH_BRIGHTNESS 0x080
#define LOW_BRIGHTNESS 0x0F
	
	unsigned short ctr, brightness = LOW_BRIGHTNESS, speed;
	
	// Software PWM ... (couldn't get the counters w/ interrupts to work)
	ctr = 0;
	unsigned int start = 0;
	for(unsigned int count = 0;;count++) {
		// create the pulse width: 
		//	0x0 - brightness	= LOW
		//	brightness - 0x3ff	= HIGH
		for(ctr = 0; ctr < 0x3FF; ctr++){
			{
				if (ctr < brightness) {
					PORTD |= _BV(PD5);
					PORTD |= _BV(PD0);
				} else {
					PORTD &= ~_BV(PD5);
					PORTD &= ~_BV(PD0);
				}
			}
		}
		if (brightness < HIGH_BRIGHTNESS) { 
			// low
			// check for IR signal
			if (!(PINC & _BV(PC2))) {
				// IR on
				brightness = HIGH_BRIGHTNESS;
				start = count;
			}
		} else {
			// high
			// shut down brightness after 100 cycles
			if (count - start > 100) {
				brightness = LOW_BRIGHTNESS;
			}
		}
	}
	return 0;
}